==> marketplace-constants-0.1.4.8.tar.gz: marketplace-constants-0.1.4.8/mpconstants/regions/ro.py <==
REGIONS = {u'ad': u'Andora',
 u'ae': u'E.A.U.',
 u'af': u'Afganistan',
 u'ag': u'Antigua \u0219i Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Albania',
 u'am': u'Armenia',
 u'an': u'Antilele Olandeze',
 u'ao': u'Angola',
 u'aq': u'Antarctica',
 u'ar': u'Argentina',
 u'as': u'Samoa American\u0103',
 u'at': u'Austria',
 u'au': u'Australia',
 u'aw': u'Aruba',
 u'ax': u'Insulele \\u00c5land',
 u'az': u'Azerbaijan',
 u'ba': u'Bosnia \u0219i Her\u021begovina',
 u'bb': u'Barbados',
 u'bd': u'Banglade\u0219',
 u'be': u'Belgia',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulgaria',
 u'bh': u'Bahrein',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Saint Barth\\u00e9lemy',
 u'bm': u'Bermude',
 u'bn': u'Brunei Darussalam',
 u'bo': u'Bolivia',
 u'br': u'Brazilia',
 u'bs': u'Insulele Bahamas',
 u'bt': u'Butan',
 u'bv': u'Insula Bouvet',
 u'bw': u'Botswana',
 u'by': u'Belarus',
 u'bz': u'Belize',
 u'ca': u'Canada',
 u'cc': u'Insulele Cocos (Keeling)',
 u'cd': u'Congo-Kinshasa',
 u'cf': u'Republica Centrafrican\u0103',
 u'cg': u'Congo-Brazzaville',
 u'ch': u'Elve\u021bia',
 u'ci': u'Coasta de Azur',
 u'ck': u'Insulele Cook',
 u'cl': u'Chile',
 u'cm': u'Camerun',
 u'cn': u'China',
 u'co': u'Columbia',
 u'cr': u'Costa Rica',
 u'cu': u'Cuba',
 u'cv': u'Capul Verde',
 u'cx': u'Insulele Christmas',
 u'cy': u'Cipru',
 u'cz': u'Republica ceh\u0103',
 u'de': u'Germania',
 u'dj': u'Djibuti',
 u'dk': u'Danemarca',
 u'dm': u'Dominica',
 u'do': u'Republica Dominican\u0103',
 u'dz': u'Algeria',
 u'ec': u'Ecuador',
 u'ee': u'Estonia',
 u'eg': u'Egipt',
 u'eh': u'Sahara de vest',
 u'er': u'Eritreea',
 u'es': u'Spania',
 u'et': u'Etiopia',
 u'fi': u'Finlanda',
 u'fj': u'Fiji',
 u'fk': u'Insulele Falkland (Malvine)',
 u'fm': u'Micronezia',
 u'fo': u'Insulele Feroe',
 u'fr': u'Fran\u021ba',
 u'ga': u'Gabon',
 u'gb': u'Marea Britanie',
 u'gd': u'Grenada',
 u'ge': u'Georgia',
 u'gf': u'Guiana Francez\u0103',
 u'gg': u'Guernsey',
 u'gh': u'Ghana',
 u'gi': u'Gibraltar',
 u'gl': u'Groenlanda',
 u'gm': u'Gambia',
 u'gn': u'Guineea',
 u'gp': u'Guadeloupe',
 u'gq': u'Guinea Ecuatorial\u0103',
 u'gr': u'Grecia',
 u'gs': u'Georgia de Sud \u0219i Insulele Sandwich de Sud',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guineea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'Hong Kong',
 u'hm': u'Insula Heard \u0219i Insulele McDonald',
 u'hn': u'Honduras',
 u'hr': u'Croa\u021bia',
 u'ht': u'Haiti',
 u'hu': u'Ungaria',
 u'id': u'Indonezia',
 u'ie': u'Irlanda',
 u'il': u'Israel',
 u'im': u'Insula Man',
 u'in': u'India',
 u'io': u'Teritoriul britanic din Oceanul Indian',
 u'iq': u'Irak',
 u'ir': u'Iran',
 u'is': u'Islanda',
 u'it': u'Italia',
 u'je': u'Jersey',
 u'jm': u'Jamaica',
 u'jo': u'Iordania',
 u'jp': u'Japonia',
 u'ke': u'Kenia',
 u'kg': u'K\xe2rg\xe2zstan',
 u'kh': u'Cambodgia',
 u'ki': u'Kiribati',
 u'km': u'Comoros',
 u'kn': u'Saint Kitts \u0219i Nevis',
 u'kp': u'Coreea de Nord',
 u'kr': u'Coreea de Sud',
 u'kw': u'Kuweit',
 u'ky': u'Insulele Cayman',
 u'kz': u'Kazahstan',
 u'la': u'Laos',
 u'lb': u'Liban',
 u'lc': u'Santa Lucia',
 u'li': u'Liechtenstein',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesoto',
 u'lt': u'Lituania',
 u'lu': u'Luxemburg',
 u'lv': u'Letonia',
 u'ly': u'Libia',
 u'ma': u'Maroc',
 u'mc': u'Monaco',
 u'md': u'Republica Moldova',
 u'me': u'Muntenegru',
 u'mf': u'Saint Martin',
 u'mg': u'Madagascar',
 u'mh': u'Insulele Marshall',
 u'mk': u'Macedonia (F.R.I.)',
 u'ml': u'Mali',
 u'mm': u'Myanmar',
 u'mn': u'Mongolia',
 u'mo': u'Monaco',
 u'mp': u'Insulele Mariana de Nord',
 u'mq': u'Martinica',
 u'mr': u'Mauritania',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauritius',
 u'mv': u'Maldive',
 u'mw': u'Malawi',
 u'mx': u'Mexic',
 u'my': u'Malaezia',
 u'mz': u'Mozambic',
 u'na': u'Namibia',
 u'nc': u'Noua Caledonie',
 u'ne': u'Niger',
 u'nf': u'Insula Norfolk',
 u'ng': u'Nigeria',
 u'ni': u'Nicaragua',
 u'nl': u'Olanda',
 u'no': u'Norvegia',
 u'np': u'Nepal',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'Noua Zeeland\u0103',
 u'om': u'Oman',
 u'pa': u'Panama',
 u'pe': u'Peru',
 u'pf': u'Polinezia Francez\u0103',
 u'pg': u'Papua Noua Guinee',
 u'ph': u'Filipine',
 u'pk': u'Pakistan',
 u'pl': u'Polonia',
 u'pm': u'Saint Pierre \u0219i Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'Porto Rico',
 u'ps': u'Teritoriile Palestiniene Ocupate',
 u'pt': u'Portugalia',
 u'pw': u'Palau',
 u'py': u'Paraguay',
 u'qa': u'Qatar',
 u're': u'Reunion',
 u'ro': u'Rom\xe2nia',
 u'rs': u'Serbia',
 u'ru': u'Rusia',
 u'rw': u'Rwanda',
 u'sa': u'Arabia Saudit\u0103',
 u'sb': u'Insulele Solomon',
 u'sc': u'Seychelles',
 u'sd': u'Sudan',
 u'se': u'Suedia',
 u'sg': u'Singapore',
 u'sh': u'Sf\xe2nta Elena',
 u'si': u'Slovenia',
 u'sj': u'Svalbard \u0219i Jan Mayen',
 u'sk': u'Slovacia',
 u'sl': u'Sierra Leone',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'Somalia',
 u'sr': u'Surinam',
 u'st': u'Sao Tome \u0219i Principe',
 u'sv': u'Salvador',
 u'sy': u'Siria',
 u'sz': u'Swaziland',
 u'tc': u'Insulele Turks \u0219i Caicos',
 u'td': u'Ciad',
 u'tf': u'Teritoriile Franceze Sudice',
 u'tg': u'Togo',
 u'th': u'Tailanda',
 u'tj': u'Tajikistan',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'Turkmenistan',
 u'tn': u'Tunisia',
 u'to': u'Tonga',
 u'tr': u'Turcia',
 u'tt': u'Trinidad \u0219i Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Taiwan',
 u'tz': u'Tanzania',
 u'ua': u'Ucraina',
 u'ug': u'Uganda',
 u'um': u'United States Minor Outlying Islands',
 u'us': u'Statele Unite',
 u'uy': u'Uruguay',
 u'uz': u'Uzbekistan',
 u'va': u'Ora\u0219ul Vatican',
 u'vc': u'Saint Vincent \u0219i Grenadine',
 u've': u'Venezuela',
 u'vg': u'Insulele Virgine Britanice',
 u'vi': u'Insulele Virgine Americane',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis \u0219i Futuna',
 u'ws': u'Samoa',
 u'ye': u'Yemen',
 u'yt': u'Mayotte',
 u'za': u'Africa de Sud',
 u'zm': u'Zambia',
 u'zw': u'Zimbabwe'}

==> marketplace-constants-0.4.0.tar.gz: marketplace-constants-0.4.0/mpconstants/regions/ro.py <==
REGIONS = {u'ad': u'Andora',
 u'ae': u'E.A.U.',
 u'af': u'Afganistan',
 u'ag': u'Antigua \u0219i Barbuda',
 u'ai': u'Anguilla',
 u'al': u'Albania',
 u'am': u'Armenia',
 u'an': u'Antilele Olandeze',
 u'ao': u'Angola',
 u'aq': u'Antarctica',
 u'ar': u'Argentina',
 u'as': u'Samoa American\u0103',
 u'at': u'Austria',
 u'au': u'Australia',
 u'aw': u'Aruba',
 u'ax': u'Insulele \xc5land',
 u'az': u'Azerbaijan',
 u'ba': u'Bosnia \u0219i Her\u021begovina',
 u'bb': u'Barbados',
 u'bd': u'Banglade\u0219',
 u'be': u'Belgia',
 u'bf': u'Burkina Faso',
 u'bg': u'Bulgaria',
 u'bh': u'Bahrein',
 u'bi': u'Burundi',
 u'bj': u'Benin',
 u'bl': u'Saint Barth\xe9lemy',
 u'bm': u'Bermude',
 u'bn': u'Brunei Darussalam',
 u'bo': u'Bolivia',
 u'br': u'Brazilia',
 u'bs': u'Insulele Bahamas',
 u'bt': u'Butan',
 u'bv': u'Insula Bouvet',
 u'bw': u'Botswana',
 u'by': u'Belarus',
 u'bz': u'Belize',
 u'ca': u'Canada',
 u'cc': u'Insulele Cocos (Keeling)',
 u'cd': u'Congo-Kinshasa',
 u'cf': u'Republica Centrafrican\u0103',
 u'cg': u'Congo-Brazzaville',
 u'ch': u'Elve\u021bia',
 u'ci': u'Coasta de Azur',
 u'ck': u'Insulele Cook',
 u'cl': u'Chile',
 u'cm': u'Camerun',
 u'cn': u'China',
 u'co': u'Columbia',
 u'cr': u'Costa Rica',
 u'cu': u'Cuba',
 u'cv': u'Capul Verde',
 u'cx': u'Insulele Christmas',
 u'cy': u'Cipru',
 u'cz': u'Republica ceh\u0103',
 u'de': u'Germania',
 u'dj': u'Djibuti',
 u'dk': u'Danemarca',
 u'dm': u'Dominica',
 u'do': u'Republica Dominican\u0103',
 u'dz': u'Algeria',
 u'ec': u'Ecuador',
 u'ee': u'Estonia',
 u'eg': u'Egipt',
 u'eh': u'Sahara de vest',
 u'er': u'Eritreea',
 u'es': u'Spania',
 u'et': u'Etiopia',
 u'fi': u'Finlanda',
 u'fj': u'Fiji',
 u'fk': u'Insulele Falkland (Malvine)',
 u'fm': u'Micronezia',
 u'fo': u'Insulele Feroe',
 u'fr': u'Fran\u021ba',
 u'ga': u'Gabon',
 u'gb': u'Marea Britanie',
 u'gd': u'Grenada',
 u'ge': u'Georgia',
 u'gf': u'Guiana Francez\u0103',
 u'gg': u'Guernsey',
 u'gh': u'Ghana',
 u'gi': u'Gibraltar',
 u'gl': u'Groenlanda',
 u'gm': u'Gambia',
 u'gn': u'Guineea',
 u'gp': u'Guadeloupe',
 u'gq': u'Guinea Ecuatorial\u0103',
 u'gr': u'Grecia',
 u'gs': u'Georgia de Sud \u0219i Insulele Sandwich de Sud',
 u'gt': u'Guatemala',
 u'gu': u'Guam',
 u'gw': u'Guineea-Bissau',
 u'gy': u'Guyana',
 u'hk': u'Hong Kong',
 u'hm': u'Insula Heard \u0219i Insulele McDonald',
 u'hn': u'Honduras',
 u'hr': u'Croa\u021bia',
 u'ht': u'Haiti',
 u'hu': u'Ungaria',
 u'id': u'Indonezia',
 u'ie': u'Irlanda',
 u'il': u'Israel',
 u'im': u'Insula Man',
 u'in': u'India',
 u'io': u'Teritoriul britanic din Oceanul Indian',
 u'iq': u'Irak',
 u'ir': u'Iran',
 u'is': u'Islanda',
 u'it': u'Italia',
 u'je': u'Jersey',
 u'jm': u'Jamaica',
 u'jo': u'Iordania',
 u'jp': u'Japonia',
 u'ke': u'Kenia',
 u'kg': u'K\xe2rg\xe2zstan',
 u'kh': u'Cambodgia',
 u'ki': u'Kiribati',
 u'km': u'Comoros',
 u'kn': u'Saint Kitts \u0219i Nevis',
 u'kp': u'Coreea de Nord',
 u'kr': u'Coreea de Sud',
 u'kw': u'Kuweit',
 u'ky': u'Insulele Cayman',
 u'kz': u'Kazahstan',
 u'la': u'Laos',
 u'lb': u'Liban',
 u'lc': u'Santa Lucia',
 u'li': u'Liechtenstein',
 u'lk': u'Sri Lanka',
 u'lr': u'Liberia',
 u'ls': u'Lesoto',
 u'lt': u'Lituania',
 u'lu': u'Luxemburg',
 u'lv': u'Letonia',
 u'ly': u'Libia',
 u'ma': u'Maroc',
 u'mc': u'Monaco',
 u'md': u'Republica Moldova',
 u'me': u'Muntenegru',
 u'mf': u'Saint Martin',
 u'mg': u'Madagascar',
 u'mh': u'Insulele Marshall',
 u'mk': u'Macedonia (F.R.I.)',
 u'ml': u'Mali',
 u'mm': u'Myanmar',
 u'mn': u'Mongolia',
 u'mo': u'Monaco',
 u'mp': u'Insulele Mariana de Nord',
 u'mq': u'Martinica',
 u'mr': u'Mauritania',
 u'ms': u'Montserrat',
 u'mt': u'Malta',
 u'mu': u'Mauritius',
 u'mv': u'Maldive',
 u'mw': u'Malawi',
 u'mx': u'Mexic',
 u'my': u'Malaezia',
 u'mz': u'Mozambic',
 u'na': u'Namibia',
 u'nc': u'Noua Caledonie',
 u'ne': u'Niger',
 u'nf': u'Insula Norfolk',
 u'ng': u'Nigeria',
 u'ni': u'Nicaragua',
 u'nl': u'Olanda',
 u'no': u'Norvegia',
 u'np': u'Nepal',
 u'nr': u'Nauru',
 u'nu': u'Niue',
 u'nz': u'Noua Zeeland\u0103',
 u'om': u'Oman',
 u'pa': u'Panama',
 u'pe': u'Peru',
 u'pf': u'Polinezia Francez\u0103',
 u'pg': u'Papua Noua Guinee',
 u'ph': u'Filipine',
 u'pk': u'Pakistan',
 u'pl': u'Polonia',
 u'pm': u'Saint Pierre \u0219i Miquelon',
 u'pn': u'Pitcairn',
 u'pr': u'Porto Rico',
 u'ps': u'Teritoriile Palestiniene Ocupate',
 u'pt': u'Portugalia',
 u'pw': u'Palau',
 u'py': u'Paraguay',
 u'qa': u'Qatar',
 u're': u'Reunion',
 u'ro': u'Rom\xe2nia',
 u'rs': u'Serbia',
 u'ru': u'Rusia',
 u'rw': u'Rwanda',
 u'sa': u'Arabia Saudit\u0103',
 u'sb': u'Insulele Solomon',
 u'sc': u'Seychelles',
 u'sd': u'Sudan',
 u'se': u'Suedia',
 u'sg': u'Singapore',
 u'sh': u'Sf\xe2nta Elena',
 u'si': u'Slovenia',
 u'sj': u'Svalbard \u0219i Jan Mayen',
 u'sk': u'Slovacia',
 u'sl': u'Sierra Leone',
 u'sm': u'San Marino',
 u'sn': u'Senegal',
 u'so': u'Somalia',
 u'sr': u'Surinam',
 u'st': u'Sao Tome \u0219i Principe',
 u'sv': u'Salvador',
 u'sy': u'Siria',
 u'sz': u'Swaziland',
 u'tc': u'Insulele Turks \u0219i Caicos',
 u'td': u'Ciad',
 u'tf': u'Teritoriile Franceze Sudice',
 u'tg': u'Togo',
 u'th': u'Tailanda',
 u'tj': u'Tajikistan',
 u'tk': u'Tokelau',
 u'tl': u'Timor-Leste',
 u'tm': u'Turkmenistan',
 u'tn': u'Tunisia',
 u'to': u'Tonga',
 u'tr': u'Turcia',
 u'tt': u'Trinidad \u0219i Tobago',
 u'tv': u'Tuvalu',
 u'tw': u'Taiwan',
 u'tz': u'Tanzania',
 u'ua': u'Ucraina',
 u'ug': u'Uganda',
 u'um': u'United States Minor Outlying Islands',
 u'us': u'Statele Unite',
 u'uy': u'Uruguay',
 u'uz': u'Uzbekistan',
 u'va': u'Ora\u0219ul Vatican',
 u'vc': u'Saint Vincent \u0219i Grenadine',
 u've': u'Venezuela',
 u'vg': u'Insulele Virgine Britanice',
 u'vi': u'Insulele Virgine Americane',
 u'vn': u'Vietnam',
 u'vu': u'Vanuatu',
 u'wf': u'Wallis \u0219i Futuna',
 u'ws': u'Samoa',
 u'ye': u'Yemen',
 u'yt': u'Mayotte',
 u'za': u'Africa de Sud',
 u'zm': u'Zambia',
 u'zw': u'Zimbabwe'}
